@@ -391,13 +391,13 @@ bool Buffer::pputc( Point & p, const unsigned char ch )
         if( pv[i]->line == p0.line && pv[i]->col > p0.col && pv[i] != &p )
           ++pv[i]->col;
       if( options.word_wrap && to_cursor( p ).col > options.rmargin() + 1 &&
-          !ISO_8859::isblank( ch ) )
+          !ISO_8859::isblank_( ch ) )
         {
         const Point pt = bot( p0 );
         Point p2 = p0;
-        while( p2 > pt && pprev( p2 ) && !ISO_8859::isblank( (*this)[p2] ) ) ;
+        while( p2 > pt && pprev( p2 ) && !ISO_8859::isblank_( (*this)[p2] ) ) ;
         Point p1 = p2;
-        while( p1 > pt && pprev( p1 ) && ISO_8859::isblank( (*this)[p1] ) ) ;
+        while( p1 > pt && pprev( p1 ) && ISO_8859::isblank_( (*this)[p1] ) ) ;
         if( p1 >= pt && p1 < p2 && pnext( p1 ) && pnext( p2 ) )
           {
           reset_appendable(); pdelb( p1, p2 ); p2 = p1;
