@@ -141,6 +141,18 @@ void Window_vector::bufhandle_menu( const int abort_key )
   }
 
 
+void Window_vector::change_buffer_name()
+  {
+  Buffer & buffer = data[_curwin].buffer();
+
+  std::string name( buffer.name() );
+  if( Menu::get_filename( "New buffer name (^C to abort): ", name ) < 0 )
+    return;
+  buffer.name( name );
+  Screen::show_status_lines( &buffer );
+  }
+
+
 void Window_vector::load_file( const int abort_key )
   {
   std::string name;
@@ -763,7 +775,7 @@ void Window_vector::copyright_update()
     {
     int year = 1900 + t->tm_year;
     while( year )
-      { year_string.insert( 0, 1, '0' + ( year % 10 ) ); year /= 10; }
+      { year_string.insert( 0U, 1, '0' + ( year % 10 ) ); year /= 10; }
     }
   history.push_back( year_string );
   if( Screen::get_string( "Year to add (^C to abort): ", history ) <= 0 )
